@@ -4,7 +4,7 @@ plotworth<-function(worthmat, main="Preferences", ylab="Estimate",
 #
 # plot ranking
 #
-#
+# uses colorspace() as from 0.8-15
 
 
 coeff<-unclass(worthmat)
@@ -25,17 +25,19 @@ if (ngroups == 1) colnames(coeff) <- ""
 
 # plotsymbols and color
 
-if (is.null(psymb)) psymb<-c(15:18,21:25)[1:nobj]
+if (is.null(psymb)) psymb<-rep(16,nobj) #psymb<-c(15:18,21:25)[1:nobj]
 
 if (is.null(pcol))
-     farbe <- rainbow(nobj)
+     farbe <- rainbow_hcl(nobj)
 else if (length(pcol)>1)
      farbe <- pcol
 else if(pcol=="black")
      farbe <- "black"
-else if(pcol %in% c("heat","topo","terrain","cm","gray"))
+else if(pcol %in% c("heat","terrain"))
+     farbe <- eval(call(paste(pcol,"_hcl",sep="",collapse=""), nobj))
+else if(pcol=="gray")
      farbe <- eval(call(paste(pcol,".colors",sep="",collapse=""), nobj))
-else farbe <- rainbow(nobj)
+else farbe <- rainbow_hcl(nobj)
 
 #     gray(0:(nobj-1) /  nobj)
 
@@ -68,6 +70,7 @@ for (i in 1:ngroups) {
   sadj<-adj[o]
   sobjnames<-objnames[o]         # sorted obj names
   spsymb<-psymb[o]               # sorted plotsymbols
+  sfarbe<-farbe[o]               # sorted colors
   scoeff<-sort(coeff[,i])        # sorted estimates
 
   x<-rep(i,nobj)
@@ -75,7 +78,7 @@ for (i in 1:ngroups) {
   xy <- xy.coords(x, scoeff)
 
   lines(c(i,i), range(scoeff), col = "gray", lty = "dotted")
-  points(xy, pch=spsymb, cex=1.5, col=farbe)
+  points(xy, pch=spsymb, cex=1.5, col=sfarbe)
   text(x+sadj*pm,scoeff,sobjnames)
 
 }
